@@ -34,7 +34,7 @@
 #include "ui/linkview/kget_linkview.h"
 #include "ui/metalinkcreator/metalinkcreator.h"
 #include "extensions/webinterface/httpserver.h"
-#ifdef DEBUG
+#ifdef DO_KGET_TEST
     #include "tests/testkget.h"
 #endif
 
@@ -425,7 +425,7 @@ void MainWindow::init()
     connect(KGet::model(), SIGNAL(groupsChangedEvent(QMap<TransferGroupHandler *, TransferGroup::ChangesFlags>)),
                            SLOT(slotGroupsChanged(QMap<TransferGroupHandler *, TransferGroup::ChangesFlags>)));
 
-#ifdef DEBUG
+#ifdef DO_KGET_TEST
     if (m_doTesting)
     {
         // Unit testing
@@ -499,7 +499,7 @@ void MainWindow::slotTransfersChanged(QMap<TransferHandler*, Transfer::ChangesFl
 void MainWindow::slotGroupsChanged(QMap<TransferGroupHandler*, TransferGroup::ChangesFlags> groups)
 {
     bool update = false;
-    foreach (TransferGroup::ChangesFlags groupFlags, groups)
+    foreach (const TransferGroup::ChangesFlags &groupFlags, groups)
     {
         if (groupFlags & TransferGroup::Gc_Percent)
         {
