@@ -15,6 +15,7 @@
 
 #include "core/kget.h"
 #include "mainwindow.h"
+#include "core/mostlocalurl.h"
 #include "core/transfertreemodel.h"
 #include "core/transfergrouphandler.h"
 #include "core/plugin/transferfactory.h"
@@ -61,14 +62,7 @@ NewTransferDialog::NewTransferDialog(QWidget *parent)
     m_timer->setSingleShot(true);
     connect(m_timer, SIGNAL(timeout()), this, SLOT(checkInput()));
 
-    //set the palettes for errors and warnings
-    KColorScheme scheme(QPalette::Active, KColorScheme::Window);
-    m_error = ui.error->palette();
-    m_error.setBrush(QPalette::WindowText, scheme.foreground(KColorScheme::NegativeText));
-    m_warning = m_error;
-    m_warning.setBrush(QPalette::WindowText, scheme.foreground(KColorScheme::NeutralText));
-
-    scheme = KColorScheme(QPalette::Active, KColorScheme::View);
+    const KColorScheme scheme = KColorScheme(QPalette::Active, KColorScheme::View);
     m_existingFileBackground = scheme.background(KColorScheme::NeutralBackground);
     m_normalBackground = scheme.background();
 
@@ -79,7 +73,7 @@ NewTransferDialog::NewTransferDialog(QWidget *parent)
     ui.destRequester->comboBox()->setEditable(true);
     ui.destRequester->fileDialog()->setKeepLocation(true);
 
-    ui.titleWidget->setPixmap(KIcon("document-new").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.errorWidget->setCloseButtonVisible(false);
 
     clear();
 
@@ -159,7 +153,7 @@ void NewTransferDialog::setSource(const KUrl::List &sources)
 
 void NewTransferDialog::setDestinationFileName(const QString &filename)
 {
-    ui.destRequester->setUrl(ui.destRequester->url().path(KUrl::AddTrailingSlash) + filename);
+    ui.destRequester->setUrl(QString(ui.destRequester->url().path(KUrl::AddTrailingSlash) + filename));
 }
 
 //TODO improve this method, so that it does not take sources and has a better name
@@ -317,10 +311,11 @@ void NewTransferDialog::checkInput()
     UrlChecker::UrlError error = UrlChecker::checkFolder(dest);
     const bool folderValid = (error == UrlChecker::NoError);
     bool destinationValid = false;
+    QString infoText;
+    QString warningText;
     if (!folderValid) {
         if (m_multiple) {
-            setError(UrlChecker::message(KUrl(), UrlChecker::Folder, error));
-
+            infoText = UrlChecker::message(KUrl(), UrlChecker::Folder, error);
         } else {
             //might be a destination instead of a folder
             destinationValid = (UrlChecker::checkDestination(dest) == UrlChecker::NoError);
@@ -328,17 +323,15 @@ void NewTransferDialog::checkInput()
     } else {
         m_destination = dest;
     }
-    ui.errorWidget->setVisible(!folderValid && !destinationValid);
 
     //check the source
     if (!m_multiple) {
-        source = KIO::NetAccess::mostLocalUrl(source, 0);
+        source = mostLocalUrl(source);
     }
     error = UrlChecker::checkSource(source);
     const bool sourceValid = (error == UrlChecker::NoError);
     if (!m_multiple && !sourceValid) {
-        setError(UrlChecker::message(KUrl(), UrlChecker::Source, error));
-        ui.errorWidget->show();
+        infoText = UrlChecker::message(KUrl(), UrlChecker::Source, error);
     }
 
     //check if any sources are checked and for existing transfers or destinations
@@ -355,8 +348,7 @@ void NewTransferDialog::checkInput()
             }
         }
         if (!filesChecked) {
-            setError(i18n("You have no source URLs selected."));
-            ui.errorWidget->show();
+            infoText = i18n("Select at least one source url.");
         }
 
         //check if there are existing files
@@ -372,10 +364,9 @@ void NewTransferDialog::checkInput()
                 } else {
                     item->setBackground(m_normalBackground);
                 }
-                if (existingFile) {
-                    setWarning(i18n("Files that exist already in the current folder have been marked."));//TODO better message
-                    ui.errorWidget->show();
-                }
+            }
+            if (existingFile) {
+                warningText = i18n("Files that exist already in the current folder have been marked.");//TODO better message
             }
         }
     }
@@ -384,34 +375,36 @@ void NewTransferDialog::checkInput()
     UrlChecker::UrlWarning warning = UrlChecker::NoWarning;
     if (!m_multiple && sourceValid && (folderValid || destinationValid)) {
         m_destination = UrlChecker::destUrl(dest, source);
-        ui.errorText->clear();
         //show only one message for existing transfers
         m_existingTransfer = UrlChecker::existingTransfer(source, UrlChecker::Source, &warning);
         if (m_existingTransfer) {
-            setWarning(UrlChecker::message(KUrl(), UrlChecker::Source, warning));
-            ui.errorWidget->show();
+            warningText = UrlChecker::message(KUrl(), UrlChecker::Source, warning);
         } else {
             m_existingTransfer = UrlChecker::existingTransfer(m_destination, UrlChecker::Destination, &warning);
             if (m_existingTransfer) {
-                setWarning(UrlChecker::message(KUrl(), UrlChecker::Destination, warning));
-                ui.errorWidget->show();
+                warningText = UrlChecker::message(KUrl(), UrlChecker::Destination, warning);
             }
         }
 
         if (UrlChecker::wouldOverwrite(KUrl(ui.urlRequester->text().trimmed()), m_destination)) {
             m_overWriteSingle = true;
-            QString warning = ui.errorText->text();
-            if (!warning.isEmpty()) {
-                warning += '\n';
+            if (!warningText.isEmpty()) {
+                warningText += '\n';
             }
-            warning += UrlChecker::message(KUrl(), UrlChecker::Destination, UrlChecker::ExistingFile);
-            setWarning(warning);
-            ui.errorWidget->show();
+            warningText += UrlChecker::message(KUrl(), UrlChecker::Destination, UrlChecker::ExistingFile);
         } else {
             m_overWriteSingle = false;
         }
     }
 
+    if (!infoText.isEmpty()) {
+        setInformation(infoText);
+    } else if (!warningText.isEmpty()) {
+        setWarning(warningText);
+    } else {
+        ui.errorWidget->hide();
+    }
+
     //activate the ok button
     if (m_multiple) {
         enableButtonOk(folderValid && filesChecked);
@@ -496,18 +489,18 @@ void NewTransferDialog::dialogAccepted()
     }
 }
 
-void NewTransferDialog::setError(const QString &error)
+void NewTransferDialog::setInformation(const QString &information)
 {
-    ui.errorText->setText(error);
-    ui.error->setText(i18nc("an error happened in connection with the user input", "Error:"));
-    ui.error->setPalette(m_error);
+    ui.errorWidget->setMessageType(KMessageWidget::Information);
+    ui.errorWidget->setText(information);
+    ui.errorWidget->setVisible(!information.isEmpty());
 }
 
 void NewTransferDialog::setWarning(const QString &warning)
 {
-    ui.errorText->setText(warning);
-    ui.error->setText(i18nc("a warning happened in connection with the user input", "Warning:"));
-    ui.error->setPalette(m_warning);
+    ui.errorWidget->setMessageType(KMessageWidget::Warning);
+    ui.errorWidget->setText(warning);
+    ui.errorWidget->setVisible(!warning.isEmpty());
 }
 
 
@@ -597,9 +590,10 @@ void NewTransferDialogHandler::showNewTransferDialog(KUrl::List urls)
     newTransferDialogHandler->m_numJobs[newTransferDialogHandler->m_nextJobId] = urls.count();
     foreach (const KUrl &url, urls) {
         //needed to avoid when protocols like the desktop protocol is used, see bko:185283
-        KIO::StatJob *job = KIO::mostLocalUrl(url, KIO::HideProgressInfo);
+        KIO::Job *job = mostLocalUrlJob(url);
         job->setProperty("jobId", (newTransferDialogHandler->m_nextJobId));
         connect(job, SIGNAL(result(KJob*)), newTransferDialogHandler, SLOT(slotMostLocalUrlResult(KJob*)));
+        job->start();
     }
 
     ++(newTransferDialogHandler->m_nextJobId);
@@ -607,7 +601,7 @@ void NewTransferDialogHandler::showNewTransferDialog(KUrl::List urls)
 
 void NewTransferDialogHandler::slotMostLocalUrlResult(KJob *j)
 {
-    KIO::StatJob *job = static_cast<KIO::StatJob*>(j);
+    MostLocalUrlJob *job = static_cast<MostLocalUrlJob*>(j);
     const int jobId = job->property("jobId").toInt();
 
     if (job->error()) {
@@ -656,7 +650,12 @@ void NewTransferDialogHandler::handleUrls(const int jobId)
         const KUrl sourceUrl = urls.first();
         const QList<TransferGroupHandler*> groups = KGet::groupsFromExceptions(sourceUrl);
         const QString groupName = (groups.isEmpty() ? QString() : groups.first()->name());
-        const QString defaultFolder = (groups.isEmpty() ? QString() : groups.first()->defaultFolder());
+        QString defaultFolder;
+        if (groups.isEmpty()) {
+            defaultFolder = (Settings::askForDestination() ? QString() : KGlobalSettings::downloadPath());
+        } else {
+            defaultFolder = groups.first()->defaultFolder();
+        }
 
         if (!folder.isEmpty()) {
             const KUrl destUrl = UrlChecker::destUrl(KUrl(folder), sourceUrl, suggestedFileName);
@@ -665,7 +664,8 @@ void NewTransferDialogHandler::handleUrls(const int jobId)
                 data << KGet::TransferData(sourceUrl, newDest, groupName);
             }
             urls.removeFirst();
-        } else if (!Settings::directoriesAsSuggestion() && (UrlChecker::checkFolder(KUrl(defaultFolder)) == UrlChecker::NoError)) {
+        } else if (((!groups.isEmpty() && !Settings::directoriesAsSuggestion()) || !Settings::askForDestination()) &&
+                   (UrlChecker::checkFolder(KUrl(defaultFolder)) == UrlChecker::NoError)) {
             const KUrl destUrl = UrlChecker::destUrl(KUrl(defaultFolder), sourceUrl, suggestedFileName);
             newDest = check.checkExistingFile(sourceUrl, destUrl);
             if (!newDest.isEmpty()) {
@@ -755,6 +755,25 @@ void NewTransferDialogHandler::handleUrls(const int jobId)
         }
     }
 
+    ///Download the rest of the urls to KGlobalSettings::downloadPath() if the user is not aksed for a destination
+    if (!Settings::askForDestination()) {
+        //the download path will be always used
+        const QString dir = KGlobalSettings::downloadPath();
+        if (!dir.isEmpty()) {
+            KUrl::List::iterator it = urls.begin();
+            while (it != urls.end()) {
+                const KUrl sourceUrl = *it;
+                const KUrl destUrl = UrlChecker::destUrl(dir, sourceUrl);
+                newDest = check.checkExistingFile(sourceUrl, destUrl);
+                if (!newDest.isEmpty()) {
+                    data << KGet::TransferData(sourceUrl, newDest);
+                }
+
+                it = urls.erase(it);
+            }
+        }
+    }
+
     ///Now create transfers for the urls that provided enough data
     if (!data.isEmpty()) {
         KGet::createTransfers(data);
