@@ -21,9 +21,9 @@
 
 #include <kdebug.h>
 
-#include <qmap.h>
-#include <qtimer.h>
-#include <qvaluelist.h>
+#include <QMap>
+#include <QTimer>
+#include <QList>
 
 namespace Kopete
 {
@@ -33,12 +33,12 @@ class MessageHandlerChainTerminator : public MessageHandler
 public:
 	void handleMessage( MessageEvent *event )
 	{
-		kdError( 14010 ) << k_funcinfo << "message got to end of chain!" << endl;
+		kError( 14010 ) << "message got to end of chain!" << endl;
 		event->discard();
 	}
 	int capabilities()
 	{
-		kdError( 14010 ) << k_funcinfo << "request got to end of chain!" << endl;
+		kError( 14010 ) << "request got to end of chain!" << endl;
 		return 0;
 	}
 };
@@ -62,7 +62,7 @@ MessageHandlerChain::Ptr MessageHandlerChain::create( ChatSession *manager, Mess
 	FactoryList factories = MessageHandlerFactory::messageHandlerFactories();
 	
 	// create a sorted list of handlers
-	typedef QValueList<MessageHandler*> HandlerList;
+	typedef QList<MessageHandler*> HandlerList;
 	typedef QMap<int,HandlerList> HandlerMap;
 	HandlerMap handlers;
 	uint count = 0;
@@ -79,7 +79,7 @@ MessageHandlerChain::Ptr MessageHandlerChain::create( ChatSession *manager, Mess
 		}
 	}
 	
-	kdDebug(14010) << k_funcinfo << "got " << count << " handlers for chain" << endl;
+	kDebug(14010) << "got " << count << " handlers for chain";
 	
 	// add the handlers to the chain
 	MessageHandler *curr = 0;
@@ -103,7 +103,7 @@ MessageHandlerChain::Ptr MessageHandlerChain::create( ChatSession *manager, Mess
 	else // empty chain: might happen for dir == Internal
 		chain->d->first = terminator;
 	
-	return chain;
+	return MessageHandlerChain::Ptr(chain);
 }
 
 MessageHandlerChain::MessageHandlerChain()
@@ -113,7 +113,7 @@ MessageHandlerChain::MessageHandlerChain()
 
 MessageHandlerChain::~MessageHandlerChain()
 {
-	kdDebug(14010) << k_funcinfo << endl;
+	kDebug(14010) ;
 	MessageHandler *handler = d->first;
 	while( handler )
 	{
@@ -128,7 +128,7 @@ MessageHandlerChain::~MessageHandlerChain()
 ProcessMessageTask *MessageHandlerChain::processMessage( const Message &message )
 {
 	MessageEvent *event = new MessageEvent( message );
-	return new ProcessMessageTask( this, event );
+	return new ProcessMessageTask( MessageHandlerChain::Ptr(this), event );
 }
 
 int MessageHandlerChain::capabilities()
@@ -151,7 +151,7 @@ public:
 ProcessMessageTask::ProcessMessageTask( MessageHandlerChain::Ptr chain, MessageEvent *event )
  : d( new Private(chain, event) )
 {
-	QTimer::singleShot( 0, this, SLOT( slotStart() ) );
+	QTimer::singleShot( 0, this, SLOT( start() ) );
 	connect( event, SIGNAL( done( Kopete::MessageEvent* ) ), this, SLOT( slotDone() ) );
 	event->message().manager()->ref();
 }
@@ -161,17 +161,25 @@ ProcessMessageTask::~ProcessMessageTask()
 	delete d;
 }
 
-void ProcessMessageTask::slotStart()
+void ProcessMessageTask::start()
 {
 	d->chain->d->first->handleMessageInternal( d->event );
 }
 
 void ProcessMessageTask::slotDone()
 {
-	d->event->message().manager()->deref();
+	if ( d->event->message().manager() ) // In case manager was deleted during exit
+		d->event->message().manager()->deref();
+
 	emitResult();
 }
 
+void ProcessMessageTask::kill(bool quite)
+{
+	Q_UNUSED(quite);
+}
+
+
 MessageEvent *ProcessMessageTask::event()
 {
 	return d->event;
