@@ -116,7 +116,7 @@ std::pair<QString,QRect> ComponentBase::toolTip( const QPoint &relativePos )
 		if ( n->rect().contains( relativePos ) )
 			return n->toolTip( relativePos );
 
-	return std::make_pair( QString::null, QRect() );
+	return std::make_pair( QString(), QRect() );
 }
 
 void ComponentBase::updateAnimationPosition( int p, int s )
@@ -707,9 +707,9 @@ void DisplayNameComponent::redraw()
 {
 	QColor color;
 	for ( uint n = 0; n < components(); ++n )
-		if( component( n )->rtti() == Rtti_TextComponent )
 	{
-		((TextComponent*)component(n))->color();
+		if( component( n )->rtti() == Rtti_TextComponent )
+			color = ((TextComponent*)component(n))->color();
 	}
 
 	QList<KEmoticonsTheme::Token> tokens;
@@ -723,7 +723,7 @@ void DisplayNameComponent::redraw()
 
 	QFontMetrics fontMetrics( d->font );
 	int fontHeight = fontMetrics.height();
-	for ( token = tokens.begin(); token != tokens.end(); ++token )
+	for ( token = tokens.constBegin(); token != tokens.constEnd(); ++token )
 	{
 		switch ( (*token).type )
 		{
@@ -1068,7 +1068,7 @@ void Item::setOpacity( float opacity )
 	repaint();
 }
 
-void Item::setSearchMatch( bool match )
+void Item::setSearchMatch( bool match, bool searching )
 {
 	d->searchMatch = match;
 
@@ -1078,7 +1078,7 @@ void Item::setSearchMatch( bool match )
 	{
 		kDebug(14000) << " match: " << match << ", vis timer active: " << d->visibilityTimer.isActive()
 		               << ", target visibility: " << targetVisibility() << endl;
-		if ( d->visibilityTimer.isActive() )
+		if ( d->visibilityTimer.isActive() || searching )
 			mySetVisible( true );
 		else
 			mySetVisible( targetVisibility() );
