@@ -21,8 +21,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "gaducommands.h"
 #include "gadusession.h"
@@ -31,14 +31,16 @@
 #include <qregexp.h>
 #include <qtextcodec.h>
 #include <qimage.h>
+//Added by qt3to4:
+#include <QPixmap>
 
 #include <klocale.h>
 #include <kdebug.h>
 
 #include <errno.h>
 
-GaduCommand::GaduCommand( QObject* parent, const char* name )
-: QObject( parent, name ), read_( 0 ), write_( 0 )
+GaduCommand::GaduCommand( QObject* parent )
+: QObject( parent ), read_( 0 ), write_( 0 )
 {
 }
 
@@ -98,14 +100,10 @@ GaduCommand::disableNotifiers()
 void
 GaduCommand::deleteNotifiers()
 {
-	if ( read_ ) {
-		delete read_;
-		read_ = NULL;
-	}
-	if ( write_ ) {
-		delete write_;
-		write_ = NULL;
-	}
+	delete read_;
+	read_ = NULL;
+	delete write_;
+	write_ = NULL;
 }
 
 void
@@ -114,13 +112,13 @@ GaduCommand::forwarder()
 	emit socketReady();
 }
 
-RegisterCommand::RegisterCommand( QObject* parent, const char* name )
-:GaduCommand( parent, name ), state( RegisterStateNoToken ), session_( 0 ), uin( 0 )
+RegisterCommand::RegisterCommand( QObject* parent )
+:GaduCommand( parent ), state( RegisterStateNoToken ), session_( 0 ), uin( 0 )
 {
 }
 
-RegisterCommand::RegisterCommand( const QString& email, const QString& password, QObject* parent, const char* name )
-:GaduCommand( parent, name ), state( RegisterStateNoToken ), email_( email ), password_( password ), session_( 0 ), uin( 0 )
+RegisterCommand::RegisterCommand( const QString& email, const QString& password, QObject* parent )
+:GaduCommand( parent ), state( RegisterStateNoToken ), email_( email ), password_( password ), session_( 0 ), uin( 0 )
 {
 }
 
@@ -139,7 +137,7 @@ unsigned int RegisterCommand::newUin()
 void
 RegisterCommand::requestToken()
 {
-	kdDebug( 14100 ) << "requestToken Initialisation" << endl;
+	kDebug( 14100 ) << "requestToken Initialisation";
 	state = RegisterStateWaitingForToken;
 
 	if ( !( session_ = gg_token( 1 ) ) ) {
@@ -175,10 +173,10 @@ RegisterCommand::execute()
 {
 	if ( state != RegisterStateGotToken || email_.isEmpty() || password_.isEmpty() || tokenString.isEmpty() ) {
 		// get token first || fill information
-		kdDebug(14100) << "not enough info to run execute, state: " << state << " , email: " << email_ << ", password present " << !password_.isEmpty() << ", token string:" << tokenString << endl;
+		kDebug(14100) << "not enough info to run execute, state: " << state << " , email: " << email_ << ", password present " << !password_.isEmpty() << ", token string:" << tokenString;
 		return;
 	}
-	session_ = gg_register3( email_.ascii(), password_.ascii(), tokenId.ascii(), tokenString.ascii(), 1 );
+	session_ = gg_register3( email_.toAscii(), password_.toAscii(), tokenId.toAscii(), tokenString.toAscii(), 1 );
 	if ( !session_ ) {
 		error( i18n( "Gadu-Gadu" ), i18n( "Registration FAILED" ) );
 		return;
@@ -204,10 +202,10 @@ void RegisterCommand::watcher()
 		}
 
 		pubDir = (struct gg_pubdir *)session_->data;
-		emit operationStatus( i18n( "Token retrieving status: %1" ).arg( GaduSession::stateDescription( session_->state ) ) );
+		emit operationStatus( i18n( "Token retrieving status: %1", GaduSession::stateDescription( session_->state ) ) );
 		switch ( session_->state ) {
 			case GG_STATE_CONNECTING:
-				kdDebug( 14100 ) << "Recreating notifiers " << endl;
+				kDebug( 14100 ) << "Recreating notifiers ";
 				deleteNotifiers();
 				checkSocket( session_->fd, 0);
 				break;
@@ -222,7 +220,7 @@ void RegisterCommand::watcher()
 			case GG_STATE_DONE:
 				struct gg_token* sp = ( struct gg_token* )session_->data;
 				tokenId = (char *)sp->tokenid;
-				kdDebug( 14100 ) << "got Token!, ID: " << tokenId << endl;
+				kDebug( 14100 ) << "got Token!, ID: " << tokenId;
 				deleteNotifiers();
 				if ( pubDir->success ) {
 					QPixmap tokenImg;
@@ -254,10 +252,10 @@ void RegisterCommand::watcher()
 			return;
 		}
 		pubDir = (gg_pubdir*) session_->data;
-		emit operationStatus( i18n( "Registration status: %1" ).arg( GaduSession::stateDescription( session_->state ) ) );
+		emit operationStatus( i18n( "Registration status: %1", GaduSession::stateDescription( session_->state ) ) );
 		switch ( session_->state ) {
 			case GG_STATE_CONNECTING:
-				kdDebug( 14100 ) << "Recreating notifiers " << endl;
+				kDebug( 14100 ) << "Recreating notifiers ";
 				deleteNotifiers();
 				checkSocket( session_->fd, 0);
 				break;
@@ -275,7 +273,7 @@ void RegisterCommand::watcher()
 				if ( pubDir->success && pubDir->uin ) {
 					uin= pubDir->uin;
 					state = RegisterStateDone;
-					emit done( i18n( "Registration Finished" ), i18n( "Registration has completed successfully." ) );
+					emit done( i18n( "Registration Finished" ), i18n( "Registration has been completed successfully." ) );
 				}
 				else {
 					emit error( i18n( "Registration Error" ), i18n( "Incorrect data sent to server." ) );
@@ -293,13 +291,13 @@ void RegisterCommand::watcher()
 	}
 }
 
-RemindPasswordCommand::RemindPasswordCommand( QObject* parent, const char* name )
-: GaduCommand( parent, name ), uin_( 0 ), session_( 0 )
+RemindPasswordCommand::RemindPasswordCommand( QObject* parent )
+: GaduCommand( parent ), uin_( 0 ), session_( 0 )
 {
 }
 
-RemindPasswordCommand::RemindPasswordCommand( uin_t uin, QObject* parent, const char* name )
-: GaduCommand( parent, name ), uin_( uin ), session_( 0 )
+RemindPasswordCommand::RemindPasswordCommand( uin_t uin, QObject* parent )
+: GaduCommand( parent ), uin_( uin ), session_( 0 )
 {
 }
 
@@ -341,7 +339,7 @@ RemindPasswordCommand::watcher()
 
 	if ( session_->state == GG_STATE_DONE ) {
 		struct gg_pubdir* p = static_cast<struct gg_pubdir*>( session_->data );
-		QString finished = (p->success) ? i18n( "Successfully" ) : i18n( "Unsuccessful. Please retry." );
+		QString finished = (p->success) ? i18n( "Success" ) : i18n( "Unsuccessful. Please retry." );
 		emit done( i18n( "Remind Password" ), i18n( "Remind password finished: " ) + finished );
 		gg_free_remind_passwd( session_ );
 		done_ = true;
@@ -351,8 +349,8 @@ RemindPasswordCommand::watcher()
 	enableNotifiers( session_->check );
 }
 
-ChangePasswordCommand::ChangePasswordCommand( QObject* parent, const char* name )
-: GaduCommand( parent, name ), session_( 0 )
+ChangePasswordCommand::ChangePasswordCommand( QObject* parent )
+: GaduCommand( parent ), session_( 0 )
 {
 }
 
