@@ -163,6 +163,22 @@ QList<KAction*> *JabberContact::customContextMenuActions ()
 	connect(removeAuthAction, SIGNAL(triggered(bool)), SLOT(slotRemoveAuth()));
 	actionAuthorization->addAction(removeAuthAction);
 
+#ifdef GOOGLETALK_SUPPORT
+
+	if ( account()->enabledGoogleTalk() ) {
+
+		KAction *googleTalkCallAction;
+		googleTalkCallAction = new KAction( this );
+		googleTalkCallAction->setIcon( (KIcon("voicecall") ) );
+		googleTalkCallAction->setText( i18n ("Call Google Talk contact") );
+		googleTalkCallAction->setEnabled( account()->supportGoogleTalk(contactId()) );
+		connect(googleTalkCallAction, SIGNAL(triggered(bool)), SLOT(makeGoogleTalkCallAction()));
+		actions->append(googleTalkCallAction);
+
+	}
+
+#endif
+
 	KActionMenu *actionSetAvailability = new KActionMenu ( KIcon("user-identity", 0, QStringList() << QString() << "user-online"), i18n ("Set Availability"), this );
 
 #define KACTION(status, text, name, slot) \
@@ -341,8 +357,12 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 					Kopete::Message m=Kopete::Message ( this, mManager->members() );
 					m.setPlainBody( i18n("%1 has ended his/her participation in the chat session.", metaContact()->displayName()) );
 					m.setDirection( Kopete::Message::Internal );
+					m.setImportance(Kopete::Message::Low);
 
-					mManager->appendMessage ( m, message.from().resource () );
+					if ( account()->mergeMessages() )
+						mManager->appendMessage ( m, QString() );
+					else
+						mManager->appendMessage ( m, message.from().resource () );
 				}
 			}
 		}
@@ -427,7 +447,10 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 	// append message to (eventually new) manager and preselect the originating resource
 	if ( newMessage )
 	{
-		mManager->appendMessage ( *newMessage, message.from().resource () );
+		if ( account()->mergeMessages() )
+			mManager->appendMessage ( *newMessage, QString() );
+		else
+			mManager->appendMessage ( *newMessage, message.from().resource () );
 
 		delete newMessage;
 	}
@@ -451,7 +474,10 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 		msg.setDirection( Kopete::Message::Inbound );
 		msg.setRequestedPlugin( viewPlugin );
 
-		mManager->appendMessage ( msg, message.from().resource () );
+		if ( account()->mergeMessages() )
+			mManager->appendMessage ( msg, QString() );
+		else
+			mManager->appendMessage ( msg, message.from().resource () );
 	}
 }
 
@@ -867,7 +893,7 @@ JabberChatSession *JabberContact::manager ( Kopete::ContactPtrList chatMembers,
 		 * will stay empty.
 		 */
 		if ( jid.resource().isEmpty () )
-			jid.withResource ( account()->resourcePool()->lockedResource ( jid ).name () );
+			jid = jid.withResource ( account()->resourcePool()->lockedResource ( jid ).name () );
 
 		kDebug(JABBER_DEBUG_GLOBAL) << "No manager found, creating a new one with resource '" << jid.resource () << "'";
 
@@ -1387,4 +1413,13 @@ void JabberContact::startJingleVideoCall()
 }
 #endif
 
+#ifdef GOOGLETALK_SUPPORT
+
+void JabberContact::makeGoogleTalkCallAction()
+{
+	account()->makeGoogleTalkCall(contactId());
+}
+
+#endif
+
 #include "jabbercontact.moc"
