@@ -769,6 +769,8 @@ void YahooAccount::slotLoginResponse( int succ , const QString &url )
 
 	//If we get here, something went wrong, so set ourselves to offline
 	initConnectionSignals( DeleteConnections );
+	errorMsg = i18nc("@info", "Could not log into the Yahoo service. Error code: <message><numid>%1</numid></message>.", succ);
+	KMessageBox::queuedMessageBox(Kopete::UI::Global::mainWidget(), KMessageBox::Error, errorMsg);
 	static_cast<YahooContact *>( myself() )->setOnlineStatus( m_protocol->Offline );
 	disconnected( Unknown );
 }
@@ -786,7 +788,7 @@ void YahooAccount::slotDisconnected()
 	QString message;
 	message = i18n( "%1 has been disconnected.\nError message:\n%2 - %3" ,
 		  accountId(), m_session->error(), m_session->errorString() );
-	KNotification::event( "connection_lost", message, myself()->onlineStatus().protocolIcon() );
+	KNotification::event( "connection_lost", message, myself()->onlineStatus().protocolIcon(KIconLoader::SizeMedium) );
 }
 
 void YahooAccount::slotLoginFailed()
@@ -799,7 +801,7 @@ void YahooAccount::slotLoginFailed()
 	QString message;
 	message = i18n( "There was an error while connecting %1 to the Yahoo server.\nError message:\n%2 - %3" ,
 		  accountId(), m_session->error(), m_session->errorString() );
-	KNotification::event( "cannot_connect", message, myself()->onlineStatus().protocolIcon() );
+	KNotification::event( "cannot_connect", message, myself()->onlineStatus().protocolIcon(KIconLoader::SizeMedium) );
 }
 
 void YahooAccount::slotError( int level )
@@ -1165,7 +1167,7 @@ void YahooAccount::slotGotConfInvite( const QString & who, const QString & room,
 	}
 	if( KMessageBox::Yes == KMessageBox::questionYesNo( Kopete::UI::Global::mainWidget(),
 		i18n("%1 has invited you to join a conference with %2.\n\nHis/her message: %3\n\nAccept?",
-				who, m, msg), QString(), KGuiItem( i18nc("@action","Accept") ), KGuiItem( i18nc("@action","Ignore") ) ) )
+				who, m, msg), QString(), KGuiItem( i18nc("@action","Accept") ), KGuiItem( i18nc("@action","Close") ) ) )
 	{
 		m_session->joinConference( room, myMembers );
 		if( !m_conferences[room] )
@@ -1608,7 +1610,7 @@ void YahooAccount::slotGotWebcamInvite( const QString& who )
 	m_pendingWebcamInvites.append( who );
 
 	if( KMessageBox::Yes == KMessageBox::questionYesNo( Kopete::UI::Global::mainWidget(), i18n("%1 has invited you to view his/her webcam. Accept?", who),
-                            QString(), KGuiItem( i18nc("@action","Accept") ), KGuiItem( i18nc("@action","Ignore") ) ) )
+                            QString(), KGuiItem( i18nc("@action","Accept") ), KGuiItem( i18nc("@action","Close") ) ) )
 	{
 		m_pendingWebcamInvites.removeAll( who );
 		m_session->requestWebcam( who );
@@ -1819,7 +1821,7 @@ void YahooAccount::slotWebcamViewerJoined( const QString &viewer )
 void YahooAccount::slotWebcamViewerRequest( const QString &viewer )
 {
 	if( KMessageBox::Yes == KMessageBox::questionYesNo( Kopete::UI::Global::mainWidget(), i18n("%1 wants to view your webcam. Grant access?",
-		viewer), QString(), KGuiItem( i18nc("@action","Accept") ), KGuiItem( i18nc("@action","Ignore") ) ) )
+		viewer), QString(), KGuiItem( i18nc("@action","Accept") ), KGuiItem( i18nc("@action","Close") ) ) )
 		m_session->grantWebcamAccess( viewer );
 }
 
